#
#  File: rh6-horde.spec
#  $Horde: horde/packaging/redhat/rh6-horde.spec,v 1.1.2.5 2001/11/14 19:50:37 bjn Exp $
#
#  This is the SPEC file for the Horde Red Hat 6.x (RPM v3) RPMs/SRPM.
#

%define apachedir /etc/httpd
%define apacheuser nobody
%define apachegroup nobody
%define contentdir /home/httpd

Summary: The common Horde Framework for all Horde modules.
Name: horde
Version: 1.2.7
Release: 1rh6
Copyright: GPL
Group: Applications/Horde
Source: ftp://ftp.horde.org/pub/horde/tarballs/horde-%{version}.tar.gz
Source1: horde.conf
Vendor: The Horde Project
URL: http://www.horde.org/
Packager: Brent J. Nordquist <bjn@horde.org>
BuildArchitectures: noarch
BuildRoot: /tmp/horde-root
Requires: php >= 3.0.16
Requires: apache >= 1.3.12
Prereq: /usr/bin/perl

%description
The Horde Framework provides a common structure and interface for Horde
modules (such as IMP, a web-based mail program).  This RPM is required
for all other Horde module RPMS.

The Horde Project writes web applications in PHP and releases them under
the GNU Public License.  For more information (including help with Horde
and its modules) please visit http://www.horde.org/.

%package mysql
Group: Applications/Horde
Summary: MySQL configuration for the Horde Framework.
Requires: horde = %{version}
Provides: horde-phplib-storage
Conflicts: horde-pgsql
Conflicts: horde-shm

%description mysql
This RPM configures the Horde Framework to use MySQL for its PHPLIB session
storage.

%package pgsql
Group: Applications/Horde
Summary: PostgreSQL configuration for the Horde Framework.
Requires: horde = %{version}
Provides: horde-phplib-storage
Conflicts: horde-mysql
Conflicts: horde-shm

%description pgsql
This RPM configures the Horde Framework to use PostgreSQL for its PHPLIB
session storage.

%package shm
Group: Applications/Horde
Summary: Shared memory configuration for the Horde Framework.
Requires: horde = %{version}
Provides: horde-phplib-storage
Conflicts: horde-mysql
Conflicts: horde-pgsql

%description shm
This RPM configures the Horde Framework to use shared memory for its PHPLIB
session storage.

%prep
%setup -q -n %{name}-%{version}

%build
perl -pi -e "s/'.*';/'hordemgr';/ if (/var\\s+\\\$(User|Password)\\s+=/);" phplib/local.inc

%install
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT%{apachedir}/conf
cp -p $RPM_SOURCE_DIR/horde.conf $RPM_BUILD_ROOT%{apachedir}/conf
mkdir -p $RPM_BUILD_ROOT%{contentdir}/html/horde
cp -pR * $RPM_BUILD_ROOT%{contentdir}/html/horde
cd $RPM_BUILD_ROOT%{contentdir}/html/horde
mv phplib ../../horde-phplib
sh install.sh
sh secure.sh

%clean
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

%post
perl -pi -e 's/$/ index.php3/ if (/DirectoryIndex\s.*index\.html/ && !/index\.php3/);' %{apachedir}/conf/httpd.conf
grep -i 'Include.*horde.conf$' %{apachedir}/conf/httpd.conf >/dev/null 2>&1
if [ $? -eq 0 ]; then
	perl -pi -e 's/^#+// if (/Include.*horde.conf$/i);' %{apachedir}/conf/httpd.conf
else
	echo "Include %{apachedir}/conf/horde.conf" >>%{apachedir}/conf/httpd.conf
fi
/sbin/service httpd restart
sleep 1  # settling time vs. installing multiple RPMs at a time

%postun
if [ $1 -eq 0 ]; then
    perl -pi -e 's/^/#/ if (/^Include.*horde.conf$/i);' %{apachedir}/conf/httpd.conf
    /sbin/service httpd restart
    sleep 1  # settling time vs. installing multiple RPMs at a time
fi

# This trigger accounts for a bug in RPMs before 1.2.2:  the old postun script
# commented this line out during an upgrade; this puts it back at the end
%triggerpostun -- horde < 1.2.2
perl -pi -e 's/^#+// if (/Include.*horde.conf$/i);' %{apachedir}/conf/httpd.conf
/sbin/service httpd restart
sleep 1  # settling time vs. installing multiple RPMs at a time

# This trigger accounts for the relocation of PHPLIB in RPMs after pre12
%triggerpostun -- horde = 1.2.0_pre12-1
mv %{contentdir}/php/local.inc.rpmsave %{contentdir}/horde-phplib >>/dev/null 2>&1
rmdir %{contentdir}/php >>/dev/null 2>&1

%post mysql
perl -pi -e 's/^#// if (/To use an SQL database/../To use shared memory/);' %{contentdir}/horde-phplib/local.inc
cat <<_EOF2_

IMPORTANT:  If you are installing for the first time, you must now
create the Horde database tables.  The following commands (run as root)
will do this:

# mysql -p <%{contentdir}/html/horde/scripts/database/mysql_create.sql
# mysqladmin -p reload

For more information on creating the database tables, please consult
%{contentdir}/html/horde/docs/DATABASE.

_EOF2_

%post pgsql
perl -pi -e 's/^#// if (/To use an SQL database/../To use shared memory/);' %{contentdir}/horde-phplib/local.inc
perl -pi -e 's/db_mysql\.inc/db_pgsql.inc/;' %{contentdir}/horde-phplib/prepend.php3
cat <<_EOF2_

IMPORTANT:  If you are installing for the first time, you must now
create the Horde database tables.  The following commands (run as postgres)
will do this:

$ sh %{contentdir}/html/horde/scripts/database/pgsql_cuser.sh
$ psql template1 <%{contentdir}/html/horde/scripts/database/pgsql_create.sql

For more information on creating the database tables, please consult
%{contentdir}/html/horde/docs/DATABASE.

_EOF2_

%post shm
perl -pi -e 's/^#// if (/To use shared memory/../To use LDAP/);' %{contentdir}/horde-phplib/local.inc
perl -pi -e 's/ct_sql\.inc/ct_shm.inc/;' %{contentdir}/horde-phplib/prepend.php3

%files
%defattr(-,root,root)
# Apache horde.conf file
%config %{apachedir}/conf/horde.conf
# Include top level with %dir so not all files are sucked in
%dir %{contentdir}/html/horde
# Include top-level files by hand
%{contentdir}/html/horde/*.php3
%{contentdir}/html/horde/*.sh
# Include these dirs so that all files _will_ get sucked in
%{contentdir}/html/horde/graphics
%{contentdir}/html/horde/lib
%{contentdir}/html/horde/locale
%{contentdir}/html/horde/scripts
%{contentdir}/html/horde/templates
# Include phplib directory, but don't include local.inc and prepend.php3
# %config files, which are included in subpackages
%dir %{contentdir}/horde-phplib
%{contentdir}/horde-phplib/[0-9_a-km-oq-z]*
%{contentdir}/horde-phplib/page.inc
# Mark documentation files with %doc and %docdir
%doc %{contentdir}/html/horde/COPYING
%doc %{contentdir}/html/horde/README
%docdir %{contentdir}/html/horde/docs
%{contentdir}/html/horde/docs
# Mark configuration files with %config and use secure permissions
# (note that .dist files are considered software; don't mark %config)
%attr(750,root,%{apachegroup}) %dir %{contentdir}/html/horde/config
%{contentdir}/html/horde/config/*.dist
%defattr(-,root,%{apachegroup})
%config %{contentdir}/html/horde/config/*.html
%config %{contentdir}/html/horde/config/*.php3
%config %{contentdir}/html/horde/config/*.txt

%files mysql
%attr(640,root,%{apachegroup}) %config %{contentdir}/horde-phplib/local.inc
%config %{contentdir}/horde-phplib/prepend.php3

%files pgsql
%attr(640,root,%{apachegroup}) %config %{contentdir}/horde-phplib/local.inc
%config %{contentdir}/horde-phplib/prepend.php3

%files shm
%attr(640,root,%{apachegroup}) %config %{contentdir}/horde-phplib/local.inc
%config %{contentdir}/horde-phplib/prepend.php3

%changelog
* Wed Nov 14 2001 Brent J. Nordquist <bjn@horde.org>
- 1.2.7 release 1

* Thu Jul 26 2001 Brent J. Nordquist <bjn@horde.org>
- 1.2.6 release 1

* Sat Feb 03 2001 Brent J. Nordquist <bjn@horde.org>
- 1.2.4 release 1

* Thu Oct 05 2000 Brent J. Nordquist <bjn@horde.org>
- 1.2.3 release 1

* Sat Sep 30 2000 Brent J. Nordquist <bjn@horde.org>
- 1.2.2 release 1:
- add post-1.2.2 patch to session.inc to fix shared memory
- remove Prefix (relocating this package will break it)
- change Prereq to Requires to avoid RPM < 3.0.3 dependency issue
- fix upgrade (-U) bug:  only comment out horde.conf if removing (-e)
- compensate for that bug in previous RPMs
- remove empty %preun sections
- fix %files regex glitch:  case insensitivity caused "<file> included twice"

* Sat Sep 09 2000 Brent J. Nordquist <bjn@horde.org>
- 1.2.1 release 1:
- remove post-1.2.0 patch

* Tue Aug 22 2000 Brent J. Nordquist <bjn@horde.org>
- 1.2.0 release 1:
- remove dashversion hack now that we're past pre
- new tarball location for horde
- replace post-pre14 patch with post-1.2.0 patch
- add PostgreSQL PHPLIB storage subpackage

* Sun Aug 06 2000 Brent J. Nordquist <bjn@horde.org>
- 1.2.0-pre14 release 1:
- separate subpackages for PHPLIB storage types (MySQL, shared memory, etc.)
- post-pre14 patch to fix test.php3 syntax errors
- remove a few empty sections
- add some settling time (1 sec.) after Apache restart

* Tue Jul 25 2000 Brent J. Nordquist <bjn@horde.org>
- 1.2.0-pre13 release 2:
- use %{apachedir} variable for /etc/httpd
- add %{apachedir}/conf as relocatable prefix
- add %{contentdir}/horde-phplib as relocatable prefix
- contributed by Dan Brown <danb35@earthlink.net>:
-   use %{apacheuser} and %{apachegroup} variables for nobody
-   use %{contentdir} variable for /home/httpd
-   restart Apache server automatically

* Fri Jul 07 2000 Brent J. Nordquist <bjn@horde.org>
- 1.2.0-pre13 release 1:
- install phplib as /home/httpd/horde-phplib to make it clear it's Horde's
- prepend.php3 is also a config. file
- no longer require php_database (can use shm for PHPLIB sessions)
- horde.conf is no longer in tarball; install it from Source1
- secure permissions for PHPLIB local.inc (so local users can't snoop)
- new secure permission rules (nobody:nobody -> root:nobody)
- don't override config. file permissions (lest "rpm -e" leave garbage)

* Tue May 30 2000 Brent J. Nordquist <bjn@horde.org>
- 1.2.0-pre12 release 1:
- RPM sets %{version} and %{release}; don't need to %define them manually
- reworded Summary and %description
- hack around version "1.2.0-pre12" for now (RPM version can't have a dash)
- new Source: location on ftp.horde.org
- added URL: and Packager:
- no Provides: Horde (modules will rely on "horde" RPM)
- added Requires: for PHP and Apache
- %build: preconfigure local.inc for most common case
- %install: copy with -p to preserve timestamps
- /etc/httpd/conf/horde.conf Horde Apache config (Include'd from httpd.conf)
- don't remove build root in %post; that runs after RPM installation
- print message after RPM install:  create database tables, restart Apache
- documentation now marked with %doc tag (goes to /usr/doc)
- config files now marked with %config tag (preserved on upgrade/uninstall)
- secure permissions for config directory (local users can't snoop)
- other minor style changes

* Mon Aug 02 1999 Dale Lovelace <dale@redhat.com>
- up to 1.0.10

* Fri Jul 09 1999 Dale Lovelace <dale@redhat.com>
- up to 1.0.9

* Thu Jul 08 1999 Dale Lovelace <dale@redhat.com>
- Up to 1.0.8
- Clean up build root

* Mon May 24 1999 Dale Lovelace <dale@redhat.com>
- Take out my wacky HORDE/config/modules file
- Made the RPM noarch
- added %defattr(-,nobody,nobody)

* Tue May 18 1999 Dale Lovelace <dale@redhat.com>
- Add new Summary: and %description from Mike Hardy <mike@itsprojects.com>

* Tue May 04 1999 Dale Lovelace <dale@redhat.com>
- Make relocatable prefix=/home/httpd/html
- Run install.sh to set perm's etc.
- Add horde/config dir files as %config

* Fri Apr 30 1999 Dale Lovelace <dale@redhat.com> 
- Build first RPM

